package Pcore::Selenium::Firefox::Profile;

use Pcore -class;

1;
__END__
=pod

=encoding utf8

=cut
